## If packages aren't installed, install them, then load them
packages <- c("deeptime", "ggplot2","gridExtra","palaeoverse")
if(length(packages[!packages %in% installed.packages()[,"Package"]]) > 0){
  install.packages(packages[!packages %in% installed.packages()[,"Package"]])
}
library("deeptime")
library("ggplot2")
library("gridExtra")
library("palaeoverse")

##If this is not called from a bash script, it is necessary to set the working directory here
#setwd("/home/location/of/files/")

#Create output directory
dir.create(file.path(getwd(), "PDFs"))

######################################################################################################################
# Custom taxon range through time plot
# This allows a range plot ordered by groups above species
# added  title = "Temporal range of taxa", plot_names = FALSE, group_by = NULL, x_pad = 0
######################################################################################################################
tax_range_time_RJG  <- function (occdf, name = "genus", min_ma = "min_ma", max_ma = "max_ma", by = "FAD", plot = FALSE, title = "Temporal range of taxa", plot_names = FALSE, group_by = NULL, x_pad = 0, x_range = NULL, y_range = NULL, margin_text = TRUE, xlabline = 3)
{
  if (is.data.frame(occdf) == FALSE) {
    stop("`occdf` should be a dataframe")
  }
  if (is.logical(plot) == FALSE) {
    stop("`plot` should be logical (TRUE/FALSE)")
  }
  if (!is.numeric(occdf[, max_ma]) || !is.numeric(occdf[, min_ma])) {
    stop("`max_ma` and `min_ma` must be of class numeric.")
  }
  if (any(c(name, min_ma, max_ma, group_by) %in% colnames(occdf) == FALSE)) {
    stop("Either `name`, `min_ma`, `max_ma`, or `group_by` is not a named column in\n`occdf`")
  }
  if (any(is.na(occdf[, name]))) {
    stop("The `name` column contains NA values")
  }
  if (any(is.na(occdf[, min_ma])) || any(is.na(occdf[, max_ma]))) {
    stop("`min_ma` and/or `max_ma` columns contain NA values")
  }
  if (!by %in% c("name", "FAD", "LAD")) {
    stop("`by` must be either \"FAD\", \"LAD\", or \"name\"")
  }
  if (any(is.na(occdf[, group_by]))) {
    stop("`group_by` contains NA values")
  }
  unique_taxa <- unique(occdf[, name])
  unique_taxa <- unique_taxa[order(unique_taxa)]
  temp_df <- data.frame(taxon = unique_taxa, taxon_id = seq(1, length(unique_taxa), 1), max_ma = rep(NA, length(unique_taxa)),
                        min_ma = rep(NA, length(unique_taxa)), range_myr = rep(NA, length(unique_taxa)), n_occ = rep(NA, length(unique_taxa)), group_by = rep (NA, length(unique_taxa)))
  for (i in seq_along(unique_taxa)) {
    vec <- which(occdf[, name] == unique_taxa[i])
    temp_df$max_ma[i] <- max(occdf[vec, max_ma])
    temp_df$min_ma[i] <- min(occdf[vec, min_ma])
    temp_df$range_myr[i] <- temp_df$max_ma[i] - temp_df$min_ma[i]
    temp_df$n_occ[i] <- length(vec)
    #RJG - If we need to group by something, we need to add this to DF
    if(!is.null(group_by)) temp_df$group_by[i] <-occdf[vec[1], group_by]
  }
  row.names(temp_df) <- NULL
  temp_df[, c("max_ma", "min_ma", "range_myr")] <- round(x = temp_df[,c("max_ma", "min_ma", "range_myr")], digits = 3)
  if (by == "FAD") {
    temp_df <- temp_df[order(temp_df$max_ma), ]
    temp_df$taxon_id <- seq_len(nrow(temp_df))
  }
  if (by == "LAD") {
    temp_df <- temp_df[order(temp_df$min_ma), ]
    temp_df$taxon_id <- seq_len(nrow(temp_df))
  }
  #RJG - now if we need to group by: since this is already ordered by FAD or LAD that is carried through as the order within each group_by category
  if (!is.null(group_by)){
    temp_df <- temp_df[order(temp_df$group_by), ]
    temp_df$taxon_id <- seq_len(nrow(temp_df))
  }

  if (plot == TRUE) {
    if(is.null(x_range)) x_range <- c(max(temp_df$max_ma), min(temp_df$min_ma))
    x_range[2]=x_range[2]-x_pad
    if(is.null(y_range)) y_range <- c(0, nrow(temp_df))

    #RJG - If plotting names, remove Y axis and labels, then add text using text. Position this to right of min age. For lots of taxa needs to be output to a device defining a sensible aspect ratio
    if (plot_names == TRUE){

         #RJG - If we are adding names in the margin, we can expand outer margin area to allow these, but we need to do this before we call plot
      if(margin_text == TRUE && !is.null(group_by)){
        maxLength=max(nchar(temp_df$group_by))
        #This is about the right amount unless modifying with cex
        par(oma=c(0,0,0,maxLength/3))
      }

      plot(x = NA, y = NA, xlim = x_range, ylim = y_range, axes = TRUE, xaxt = "n", xlab = NA, yaxt = "n", ylab = NA, main = title)

      #RJG - add grey boxes
      periods<-GTS2020[which(GTS2020$rank=="period"),]
      for(i in 1:length(periods)){
        if(i%%2==0){
        graphics::rect(periods[i,]$max_ma, graphics::par()$usr[3], periods[i,]$min_ma, graphics::par()$usr[4], col = c("grey90", "white"), border = NA)
        }
      }
      #Add a border over the grey boxes to make the axis look OK
      graphics::rect(graphics::par()$usr[1], graphics::par()$usr[3], graphics::par()$usr[2], graphics::par()$usr[4], col = NA, border = "black")

      text(x = temp_df$min_ma, y = temp_df$taxon_id, temp_df$taxon, cex = 0.8, pos = 4)
      #Add labels for group_by
      if (!is.null(group_by)){
        unique_groups <- unique(temp_df$group_by)
        for (i in seq_along(unique_groups)) {
          vec <- which(temp_df$group_by == unique_groups[i])
          maxLength=max(nchar(temp_df$taxon[vec]))+2
          minMa <- min(temp_df$min_ma[vec])
          max <-max(vec)
          min <-min(vec)
          if(margin_text == TRUE) mtext(unique_groups[i], side = 4, at = (min + max)/2, las = 1, line = 0.1)
          else text(x = minMa - (maxLength*3), y = (min + max)/2, unique_groups[i], pos = 4)
          if(min > 1) abline(h = min -.5, col="grey")
        }
      }
    }
    else {
      plot(x = NA, y = NA, xlim = x_range, ylim = y_range, axes = TRUE, xaxt = "n", xlab = NA, ylab = "Taxon ID", main = title)
    }
    segments(x0 = temp_df$max_ma, x1 = temp_df$min_ma, y0 = temp_df$taxon_id, col = "black")
    points(x = temp_df$max_ma, y = temp_df$taxon_id, pch = 20, col = "black")
    points(x = temp_df$min_ma, y = temp_df$taxon_id, pch = 20, col = "black")

    #RJG - customisations to plot for his publication - change dates to intervals, do 1DP, and move closer to axis
    axis_geo(side = 1, intervals = "periods", exact = TRUE, round=1, cex.axis = 0.9, padj = -1)
    title(xlab = "Time (Ma)", line = xlabline)
  }
  return(temp_df)
}

######################################################################################################################
# Data preparation
######################################################################################################################

#Colour scheme accessed using:
#show_col(viridis_pal()(20))

#Read in data skipping the lines of info from PBDB
#This is the full data with no modifiers
occurenceData<-read.csv('Dunlop_Garwood_scorpiones_pbdb_data_genus_May_24.csv', skip = 18)
#If running this manually, this will create a range plot
#tax_range_time(occdf = occurenceData, name = "genus", plot = TRUE)

#Now clean the data - there are several errors that need fixing
#Eoscorpius primaevus is a fish - remove
occurenceData<-subset(occurenceData, !(accepted_name == "Eoscorpius primaevus"))

#Microlabis --> Microlabius - this is a typo in PBDB
occurenceData$genus <- gsub('Microlabis', 'Microlabius', occurenceData$genus)
occurenceData$identified_name <- gsub('Microlabis', 'Microlabius', occurenceData$identified_name)
occurenceData$accepted_name <- gsub('Microlabis', 'Microlabius', occurenceData$accepted_name)

#This was first described as Palaeophonus in 1885 as per the PBDB entry, but was then moved through to Proscorpius a year later
occurenceData$genus[which(occurenceData$occurrence_no ==1190059)]<-'Proscorpius'

#Another typo - this one is originally an error introduced in Jeram 1994
occurenceData$genus <- gsub('Pseudarchaeoctonus','Pseudoarchaeoctonus', occurenceData$genus)
occurenceData$identified_name <- gsub('Pseudarchaeoctonus', 'Pseudoarchaeoctonus', occurenceData$identified_name)
occurenceData$accepted_name <- gsub('Pseudarchaeoctonus', 'Pseudoarchaeoctonus', occurenceData$accepted_name)

#A third typo in PBDB
occurenceData$genus <- gsub('Acanthracochaerilus','Acanthracochaerilus', occurenceData$genus)
occurenceData$identified_name <- gsub('Acanthracochaerilus', 'Acanthracochaerilus', occurenceData$identified_name)
occurenceData$accepted_name <- gsub('Acanthracochaerilus', 'Acanthracochaerilus', occurenceData$accepted_name)

#I can find no evidence this has been recombined
occurenceData$genus[which(occurenceData$occurrence_no ==1190123)]<-'Opsieobuthus'

#Add Suraju itayma
Suraju<-occurenceData[1,]
Suraju<-Suraju[-1,]
Suraju[1,]<-NA
Suraju[1,]$genus<-"Suraju"
Suraju[1,]$max_ma<-259.5 # based on other fossils in the same formation in PBDB
Suraju[1,]$min_ma<-254.1 # But there is broad uncertainty about the formations age in the literature
Suraju[1,]$accepted_name<-"Suraju itayma"
Suraju[1,]$accepted_rank<-"species"
Suraju[1,]$ref_pubyr<-2020
occurenceData<-rbind(occurenceData,Suraju)
rm(Suraju)

#Add Sucinlourencous
Sucinlourencous<-occurenceData[1,]
Sucinlourencous<-Sucinlourencous[-1,]
Sucinlourencous[1,]<-NA
Sucinlourencous[1,]$genus<-"Sucinlourencous"
Sucinlourencous[1,]$max_ma<-99.6 # based on other Myanmar specimens in this dataset
Sucinlourencous[1,]$min_ma<-93.5 #
Sucinlourencous[1,]$accepted_name<-"Sucinlourencous adrianae"
Sucinlourencous[1,]$accepted_rank<-"species"
Sucinlourencous[1,]$ref_pubyr<-2015
occurenceData<-rbind(occurenceData,Sucinlourencous)
rm(Sucinlourencous)

#Add Archaeoananteroides
Archaeoananteroides<-occurenceData[1,]
Archaeoananteroides<-Archaeoananteroides[-1,]
Archaeoananteroides[1,]<-NA
Archaeoananteroides[1,]$genus<-"Archaeoananteroides"
Archaeoananteroides[1,]$max_ma<-99.6 # based on other Myanmar specimens in this dataset
Archaeoananteroides[1,]$min_ma<-93.5 #
Archaeoananteroides[1,]$accepted_name<-"Archaeoananteroides maderai"
Archaeoananteroides[1,]$accepted_rank<-"species"
Archaeoananteroides[1,]$ref_pubyr<-2016
occurenceData<-rbind(occurenceData,Archaeoananteroides)
rm(Archaeoananteroides)

#Waeringoscorpio (taxon #87) includes Labriscorpio alliedensis in PBDB data based on
#R. L. Leary. 1980. Labriscorpio alliedensis: a new Carboniferous scorpion from Rock Island County, Illinois. Journal of Paleontology 54:1255-1257
#However, only the families, not the genera, have been synonymised in
#Dunlop, J.A., Erik Tetlie, O. and Prendini, L., 2008. Reinterpretation of the Silurian scorpion Proscorpius osborni (Whitfield): integrating data from Palaeozoic and Recent scorpions. Palaeontology, 51(2), pp.303-320.
#Fix this - find accepted_name Labriscorpio alliedensis, and modify genus
occurenceData$genus[which(occurenceData$accepted_name == 'Labriscorpio alliedensis')]<-'Labriscorpio'

#We also need to record when first described - not all records in PBDB have this, rather they refer to where the info was sourced from
occurenceData$yearSpeciesPublished<-occurenceData$ref_pubyr
#Now fix species that need fixing
occurenceData$yearSpeciesPublished[which(occurenceData$genus == 'Tityus')]<-1836
occurenceData$yearSpeciesPublished[which(occurenceData$genus == 'Proscorpius')]<-1885
occurenceData$yearSpeciesPublished[which(occurenceData$genus == 'Centromachus')]<-1885
occurenceData$yearSpeciesPublished[which(occurenceData$genus == 'Palaeoscorpius')]<-1944
occurenceData$yearSpeciesPublished[which(occurenceData$genus == 'Spongiophonus')]<-1947
occurenceData$yearSpeciesPublished[which(occurenceData$genus == 'Buthiscorpius')]<-1953
occurenceData$yearSpeciesPublished[which(occurenceData$genus == 'Eskiscorpio')]<-1986

######################################################################################################################
# Taxonomy range plots
######################################################################################################################


###########################################################
# Vanilla range plot for all our fossils

pdf("PDFs/scorpion_range_plot.pdf", width = 12, height = 16)
#Adjust the margins to avoid losing the ends of the X labels
mar.default <- c(5,4,4,2) + 0.1
par(mar = mar.default + c(2, 0, 0, 0))
#Plot
tax_range_time_RJG(occdf = occurenceData, name = "genus", plot = TRUE, title="The scorpion fossil record", plot_names = TRUE, x_pad = 45, xlabline = 5)
dev.off()

###########################################################
# Thorell and Lindstrom 1885

## Create a column for the families that the authors use
occurenceData$Thorell_Lindstrom_1885 = NA
## Create a list of lists to reflect these authors taxonomy
## Each list features the genera which the authors placed in each family
Thorell_Lindstrom_1885 <- list(
  Palaeophonidae=list("Palaeophonus"),
  Cyclophthalmidae=list("Cyclophthalmus"),
  Eoscorpioidae=list("Eoscorpius","Centromachus")
)

## Add this to the occurrenceData dataframe - for each member of every genus this adds the family the authors placed this genus in in their publication
for(i in 1:length(Thorell_Lindstrom_1885))
  for(j in 1:length(Thorell_Lindstrom_1885[[i]]))
    occurenceData$Thorell_Lindstrom_1885[which(occurenceData$genus == Thorell_Lindstrom_1885[[i]][j])]<-names(Thorell_Lindstrom_1885)[i]

## Now subset this to create a dataframe with just these taxa in it
occurenceDataThorell_Lindstrom<-subset(occurenceData, !is.na(Thorell_Lindstrom_1885))
#And make sure they were described by this point in time
occurenceDataThorell_Lindstrom<-occurenceDataThorell_Lindstrom[which(occurenceDataThorell_Lindstrom$yearSpeciesPublished<1886),]

## Now plot this
pdf("PDFs/Thorell_Lindstrom.pdf", width = 8, height = 5)
#If I don't adjust the margins, we lose the X label
mar.default <- c(5,4,4,2) + 0.1
par(mar = mar.default + c(2, 0, 0, 0))
tax_range_time_RJG(occdf = occurenceDataThorell_Lindstrom, name = "genus", plot = TRUE, by="FAD", group_by = "Thorell_Lindstrom_1885", title="Thorell and Lindström 1885", plot_names = TRUE, x_pad=50, x_range = c(430, 250))
dev.off()

###########################################################

# Fritsch 1904
occurenceData$fritsch_1904 = NA
fritsch1904 <- list(
  Palaeophonidae=list("Palaeophonus","Proscorpius"),
  Anthracoscorpii=list("Cyclophthalmus","Eobuthus","Eoscorpius","Feistmantelia","Isobuthus","Mazonia","Microlabius","Palaeomachus")
)
for(i in 1:length(fritsch1904))
  for(j in 1:length(fritsch1904[[i]]))
    occurenceData$fritsch_1904[which(occurenceData$genus == fritsch1904[[i]][j])]<-names(fritsch1904)[i]
occurenceDataFritsch04<-subset(occurenceData, !is.na(fritsch_1904))
occurenceDataFritsch04<-occurenceDataFritsch04[which(occurenceDataFritsch04$yearSpeciesPublished<1905),]

pdf("PDFs/Fritsch_1904.pdf", width = 8, height = 5.5)
mar.default <- c(5,4,4,2) + 0.1
par(mar = mar.default + c(2, 0, 0, 0))
tax_range_time_RJG(occdf = occurenceDataFritsch04, name = "genus", plot = TRUE, by="FAD", group_by = "fritsch_1904", title="Frič 1904", plot_names = TRUE, x_pad=20, x_range = c(445, 250))
dev.off()

###########################################################

# Pocock 1911
occurenceData$pocock_1911 = NA
pocock_1911 <- list(
  Lobosterni=list("Eobuthus","Isobuthus"),
  Orthosterni=list("Cyclophthalmus","Microlabius","Anthracoscorpio","Archaeoctonus") # Note it is Archaeooctonus in Pocock 1911
)
for(i in 1:length(pocock_1911))
  for(j in 1:length(pocock_1911[[i]]))
    occurenceData$pocock_1911[which(occurenceData$genus == pocock_1911[[i]][j])]<-names(pocock_1911)[i]
occurenceDataPocock11<-subset(occurenceData, !is.na(pocock_1911))
occurenceDataPocock11<-occurenceDataPocock11[which(occurenceDataPocock11$yearSpeciesPublished<1912),]

pdf("PDFs/Pocock_1911.pdf", width = 8, height = 5)
mar.default <- c(5,4,4,2) + 0.1
tax_range_time_RJG(occdf = occurenceDataPocock11, name = "genus", plot = TRUE, by="FAD", group_by = "pocock_1911", title="Pocock 1911", plot_names = TRUE, x_pad=30, x_range = c(365, 280))
dev.off()

###########################################################

# Petrunkevitch 1913
occurenceData$petrunkevitch_1913 = NA
petrunkevitch_1913 <- list(
  Palaeophonidae=list("Palaeophonus","Proscorpius"),
  Cyclophthalmidae=list("Cyclophthalmus","Archaeoctonus","Palaeomachus"),
  Eoscorpionidae=list("Eoscorpius","Microlabius","Palaeopisthacanthus","Trigonoscorpio"),
  Isobuthidae=list("Eobuthus","Isobuthus","Palaeobuthus"),
  Mazoniidae=list("Mazonia")
)
for(i in 1:length(petrunkevitch_1913))
  for(j in 1:length(petrunkevitch_1913[[i]]))
    occurenceData$petrunkevitch_1913[which(occurenceData$genus == petrunkevitch_1913[[i]][j])]<-names(petrunkevitch_1913)[i]
occurenceDataPetrunkevitch13<-subset(occurenceData, !is.na(petrunkevitch_1913))
occurenceDataPetrunkevitch13<-occurenceDataPetrunkevitch13[which(occurenceDataPetrunkevitch13$yearSpeciesPublished<1914),]

#These are the obsolete genera - write them to our subsetted data table based on occurrence_no
occurenceDataPetrunkevitch13$genus[which(occurenceDataPetrunkevitch13$occurrence_no==1150458)]<-'Trigonoscorpio'
#In this case the family is still the same, so it's fine to just do this

pdf("PDFs/Petrunkevitch_1913.pdf", width = 8, height = 5)
mar.default <- c(5,4,4,2) + 0.1
tax_range_time_RJG(occdf = occurenceDataPetrunkevitch13, name = "genus", plot = TRUE, by="FAD", group_by = "petrunkevitch_1913", title="Petrunkevitch 1913", plot_names = TRUE, x_pad=75, x_range = c(445, 290))
dev.off()

###########################################################

# Petrunkevitch 1949
occurenceData$petrunkevitch_1949 = NA
petrunkevitch_1949 <- list(
  Palaeophonidae=list("Palaeophonus","Dolichophonus"),
  Mazoniidae=list("Mazonia"),
  Archaeotonidae=list("Archaeoctonus","Eoctonus","Palaeomachus"),
  Cyclophthalmidae=list("Cyclophthalmus","Centromachus"),#Not Cyclophthlmidae I assume as in draft image
  Eoscorpionidae=list("Alloscorpius","Anthracoscorpio","Compsoscorpius","Eoscorpius", "Europhthalmus","Lichnophthalmus","Lichnoscorpius","Palaeopisthacanthus","Trigonoscorpio","Typhlopisthacanthus","Typhloscorpius"),
  Isobuthidae=list("Eobuthus","Isobuthus")
)
for(i in 1:length(petrunkevitch_1949))
  for(j in 1:length(petrunkevitch_1949[[i]]))
    occurenceData$petrunkevitch_1949[which(occurenceData$genus == petrunkevitch_1949[[i]][j])]<-names(petrunkevitch_1949)[i]

occurenceDataPetrunkevitch49<-subset(occurenceData, !is.na(petrunkevitch_1949))
occurenceDataPetrunkevitch49<-occurenceDataPetrunkevitch49[which(occurenceDataPetrunkevitch49$yearSpeciesPublished<1950),]

#These are the obsolete genera - write them to our subsetted data table based on occurrence_no
occurenceDataPetrunkevitch49$genus[which(occurenceDataPetrunkevitch49$occurrence_no==1150458)]<-'Trigonoscorpio'
occurenceDataPetrunkevitch49$genus[which(occurenceDataPetrunkevitch49$occurrence_no==1150447)]<-'Alloscorpius'
occurenceDataPetrunkevitch49$genus[which(occurenceDataPetrunkevitch49$occurrence_no==1150457)]<-'Alloscorpius'
occurenceDataPetrunkevitch49$genus[which(occurenceDataPetrunkevitch49$occurrence_no==1190108)]<-'Europhthalmus'
occurenceDataPetrunkevitch49$genus[which(occurenceDataPetrunkevitch49$occurrence_no==1235486)]<-'Europhthalmus'
occurenceDataPetrunkevitch49$genus[which(occurenceDataPetrunkevitch49$occurrence_no==1151248)]<-'Lichnophthalmus'
occurenceDataPetrunkevitch49$genus[which(occurenceDataPetrunkevitch49$occurrence_no==1190107)]<-'Lichnophthalmus'
occurenceDataPetrunkevitch49$genus[which(occurenceDataPetrunkevitch49$occurrence_no==1190082)]<-'Lichnoscorpius'
occurenceDataPetrunkevitch49$genus[which(occurenceDataPetrunkevitch49$occurrence_no==1226670)]<-'Typhlopisthacanthus'
occurenceDataPetrunkevitch49$genus[which(occurenceDataPetrunkevitch49$occurrence_no==1236229)]<-'Typhloscorpius'
#In this case the family is still the same, so it's fine to just do this

pdf("PDFs/Petrunkevitch_1949.pdf", width = 8, height = 6)
mar.default <- c(5,4,4,2) + 0.1
tax_range_time_RJG(occdf = occurenceDataPetrunkevitch49, name = "genus", plot = TRUE, by="FAD", group_by = "petrunkevitch_1949", title="Petrunkevitch 1949", plot_names = TRUE, x_pad=75, x_range = c(445, 290))
dev.off()

###########################################################

# Petrunkevitch 1953
occurenceData$petrunkevitch_1953 = NA
petrunkevitch_1953 <- list(
  Palaeophonidae=list("Palaeophonus"),
  Dolichophonidae=list("Dolichophonus", "Proscorpius"),
  Mazoniidae=list("Mazonia"),
  Archaeoctonidae=list("Archaeoctonus","Eoctonus"),
  Centromachidae=list("Centromachus"),
  Cyclophthalmidae=list("Cyclophthalmus"),
  Isobuthidae=list("Palaeobuthus","Isobuthus","Microlabius"),
  Mesophonidae=list("Mesophonus","Spongiophonus"),
  Palaeoscorpionidae=list("Palaeoscorpius"),
  #Buthidae=list("Tityus"),
  Eoscorpionidae=list("Alloscorpius","Anthracoscorpio","Buthiscorpius","Compsoscorpius","Eoscorpius","Europhthalmus","Garnettius","Lichnophthalmus","Lichnoscorpius","Palaeopisthacanthus","Trigonoscorpio","Typhlopisthacanthus","Typhloscorpius")
)
for(i in 1:length(petrunkevitch_1953))
  for(j in 1:length(petrunkevitch_1953[[i]]))
    occurenceData$petrunkevitch_1953[which(occurenceData$genus == petrunkevitch_1953[[i]][j])]<-names(petrunkevitch_1953)[i]

occurenceDataPetrunkevitch53<-subset(occurenceData, !is.na(petrunkevitch_1953))
occurenceDataPetrunkevitch53<-occurenceDataPetrunkevitch53[which(occurenceDataPetrunkevitch53$yearSpeciesPublished<1954),]

#These are the obsolete genera - write them to our subsetted data table based on occurrence_no
occurenceDataPetrunkevitch53$genus[which(occurenceDataPetrunkevitch53$occurrence_no==1150458)]<-'Trigonoscorpio'
occurenceDataPetrunkevitch53$genus[which(occurenceDataPetrunkevitch53$occurrence_no==1150447)]<-'Alloscorpius'
occurenceDataPetrunkevitch53$genus[which(occurenceDataPetrunkevitch53$occurrence_no==1150457)]<-'Alloscorpius'
occurenceDataPetrunkevitch53$genus[which(occurenceDataPetrunkevitch53$occurrence_no==1190108)]<-'Europhthalmus'
occurenceDataPetrunkevitch53$genus[which(occurenceDataPetrunkevitch53$occurrence_no==1235486)]<-'Europhthalmus'
occurenceDataPetrunkevitch53$genus[which(occurenceDataPetrunkevitch53$occurrence_no==1151248)]<-'Lichnophthalmus'
occurenceDataPetrunkevitch53$genus[which(occurenceDataPetrunkevitch53$occurrence_no==1190107)]<-'Lichnophthalmus'
occurenceDataPetrunkevitch53$genus[which(occurenceDataPetrunkevitch53$occurrence_no==1190082)]<-'Lichnoscorpius'
occurenceDataPetrunkevitch53$genus[which(occurenceDataPetrunkevitch53$occurrence_no==1226670)]<-'Typhlopisthacanthus'
occurenceDataPetrunkevitch53$genus[which(occurenceDataPetrunkevitch53$occurrence_no==1236229)]<-'Typhloscorpius'
#In this case the family is still the same, so it's fine to just do this

pdf("PDFs/Petrunkevitch_1953.pdf", width = 8, height = 7)
mar.default <- c(5,4,4,2) + 0.1
tax_range_time_RJG(occdf = occurenceDataPetrunkevitch53, name = "genus", plot = TRUE, by="FAD", group_by = "petrunkevitch_1953", title="Petrunkevitch 1953", plot_names = TRUE, x_pad=20, x_range = c(445, 200))
dev.off()

###########################################################

# Petrunkevitch 1955
occurenceData$petrunkevitch_1955 = NA
petrunkevitch_1955 <- list(
  Palaeophonidae=list("Palaeophonus"),
  Dolichophonidae=list("Dolichophonus", "Proscorpius"),
  Mazoniidae=list("Mazonia"),
  Archaeoctonidae=list("Archaeoctonus","Eoctonus"),
  Centromachidae=list("Centromachus"),
  Cyclophthalmidae=list("Cyclophthalmus"),
  Isobuthidae=list("Palaeobuthus","Isobuthus","Microlabius"),
  Mesophonidae=list("Mesophonus","Spongiophonus"),
  Palaeoscorpiidae=list("Palaeoscorpius"),
  Buthidae=list("Tityus"),
  Eoscorpionidae=list("Alloscorpius","Anthracoscorpio","Buthiscorpius","Compsoscorpius","Eoscorpius","Europhthalmus","Garnettius","Lichnophthalmus","Lichnoscorpius","Palaeopisthacanthus","Trigonoscorpio","Typhlopisthocanthus","Typhloscorpius"),
  Scorpionidae=list("Mioscorpio")
)
for(i in 1:length(petrunkevitch_1955))
  for(j in 1:length(petrunkevitch_1955[[i]]))
    occurenceData$petrunkevitch_1955[which(occurenceData$genus == petrunkevitch_1955[[i]][j])]<-names(petrunkevitch_1955)[i]

occurenceDataPetrunkevitch55<-subset(occurenceData, !is.na(petrunkevitch_1955))
occurenceDataPetrunkevitch55<-occurenceDataPetrunkevitch55[which(occurenceDataPetrunkevitch55$yearSpeciesPublished<1956),]
#In 55 Miscorpio was still scorpio - add a note to reflect this
occurenceDataPetrunkevitch55$genus[which(occurenceDataPetrunkevitch55$genus == 'Mioscorpio')]<-'Mioscorpio (as Scorpio)'

#These are the obsolete genera - write them to our subsetted data table based on occurrence_no
occurenceDataPetrunkevitch55$genus[which(occurenceDataPetrunkevitch55$occurrence_no==1150458)]<-'Trigonoscorpio'
occurenceDataPetrunkevitch55$genus[which(occurenceDataPetrunkevitch55$occurrence_no==1150447)]<-'Alloscorpius'
occurenceDataPetrunkevitch55$genus[which(occurenceDataPetrunkevitch55$occurrence_no==1150457)]<-'Alloscorpius'
occurenceDataPetrunkevitch55$genus[which(occurenceDataPetrunkevitch55$occurrence_no==1190108)]<-'Europhthalmus'
occurenceDataPetrunkevitch55$genus[which(occurenceDataPetrunkevitch55$occurrence_no==1235486)]<-'Europhthalmus'
occurenceDataPetrunkevitch55$genus[which(occurenceDataPetrunkevitch55$occurrence_no==1151248)]<-'Lichnophthalmus'
occurenceDataPetrunkevitch55$genus[which(occurenceDataPetrunkevitch55$occurrence_no==1190107)]<-'Lichnophthalmus'
occurenceDataPetrunkevitch55$genus[which(occurenceDataPetrunkevitch55$occurrence_no==1190082)]<-'Lichnoscorpius'
occurenceDataPetrunkevitch55$genus[which(occurenceDataPetrunkevitch55$occurrence_no==1226670)]<-'Typhlopisthacanthus'
occurenceDataPetrunkevitch55$genus[which(occurenceDataPetrunkevitch55$occurrence_no==1236229)]<-'Typhloscorpius'
#In this case the family is still the same, so it's fine to just do this

pdf("PDFs/Petrunkevitch_1955.pdf", width = 8, height = 7)
mar.default <- c(5,4,4,2) + 0.1
tax_range_time_RJG(occdf = occurenceDataPetrunkevitch55, name = "genus", plot = TRUE, by="FAD", group_by = "petrunkevitch_1955", title="Petrunkevitch 1955", plot_names = TRUE, x_pad=20, x_range = c(445, 0))
dev.off()

##########################

# Kjellesvig Waering 1987
#Tiphoscorpio omitted as its an arthropleurid
occurenceData$kjellesvig_waering_1987 = NA
kjellesvig_waering_1987 <- list(
  Proscorpiidae=list("Proscorpius","Archaeophonus"),
  Waeringoscorpionidae=list("Waeringoscorpio"),
  Labriscorpionidae=list("Labriscorpio"),
  Palaeoscorpiidae=list("Palaeoscorpius"),
  Hydroscorpiidae=list("Hydroscorpius"),
  Archaeoctonidae=list("Archaeoctonus","Pseudoarchaeoctonus"),
  Acanthoscorpionidae=list("Acanthoscorpio"),
  Stenoscorpionidae=list("Stenoscorpio"),
  Gigantoscorpionidae=list("Gigantoscorpio"),
  Garnettiidae=list("Garnettius"),
  Mesophonidae=list("Mesophonus"),
  Mazoniidae=list("Mazonia"),
  Centromachidae=list("Centromachus"),
  Heloscorpionidae=list("Heloscorpio"),
  Liassoscorpionidae=list("Liassoscorpionides"),
  Phoxioscorpionidae=list("Phoxiscorpio"),
  Willsiscorpionidae=list("Willsiscorpio"),
  Eoctonidae=list("Eoctonus"),
  Buthiscorpiidae=list("Buthiscorpius"),
  Allobuthiscorpiidae=list("Aspiscorpio"),
  Anthracoscorpionidae=list("Anthracoscorpio", "Allobuthus"),
  Spongiophonoidae=list("Spongiophonus"),
  Praearcturidae=list("Praearcturus","Brontoscorpio"),
  Cyclophthalmidae=list("Cyclophthalmus"),
  Microlabiidae=list("Microlabius"),
  Palaeobuthidae=list("Palaeobuthus"),
  Palaeophonidae=list("Palaeophonus"),
  Anthracochaerilidae=list("Anthracochaerilus"),
  Isobuthidae=list("Isobuthus", "Feistmantelia", "Boreoscorpio", "Bromsgroviscorpio"),
  Eobuthidae=list("Eobuthus"),
  Eoscorpiidae=list("Eoscorpius","Trachyscorpio","Eskiscorpio"),
  Pareobuthidae=list("Pareobuthus"),
  Paraisobuthidae=list("Paraisobuthus", "Leioscorpio"),
  Telmatoscorpionidae=list("Telmatoscorpio"),
  Scoloposcorpionidae=list("Benniescorpio","Scoloposcorpio"),
  Opsieobuthidae=list("Opsieobuthus"),
  Loboarchaeoctonidae=list("Loboarchaeoctonus"),
  Petaloscorpionidae=list("Petaloscorpio"),
  Waterstoniidae=list("Waterstonia"),
  Branchioscorpionidae=list("Branchioscorpio"),
  Dolichophonidae=list("Dolichophonus"),
  Palaeopisthacanthidae=list("Palaeopisthacanthus","Compsoscorpius"),
  Scorpionidae=list("Mioscorpio"),
  Kronoscorpionidae=list("Kronoscorpio"),
  Incertae_sedis=list("Titanoscorpio","Wattisonia","Palaeomachus")
)

for(i in 1:length(kjellesvig_waering_1987))
  for(j in 1:length(kjellesvig_waering_1987[[i]]))
    occurenceData$kjellesvig_waering_1987[which(occurenceData$genus == kjellesvig_waering_1987[[i]][j])]<-names(kjellesvig_waering_1987)[i]

#Here we need to sort out the taxonomy elements in our subsetted version of KW
#Do this here because it requires us to change the genus in the occurrence data itself to a now obsolete term
#Subset the data
occurenceDataKjellesvigWaering87<-subset(occurenceData, !is.na(kjellesvig_waering_1987))
occurenceDataKjellesvigWaering87<-occurenceDataKjellesvigWaering87[which(occurenceDataKjellesvigWaering87$yearSpeciesPublished<1987),]

#These are the obsolete genera - write them to our subsetted data table based on occurrence_no
occurenceDataKjellesvigWaering87$genus[which(occurenceDataKjellesvigWaering87$occurrence_no==1190060)]<-'Stoermeroscorpio'
occurenceDataKjellesvigWaering87$genus[which(occurenceDataKjellesvigWaering87$occurrence_no ==1190079)]<-'Allobuthiscorpius'
occurenceDataKjellesvigWaering87$genus[which(occurenceDataKjellesvigWaering87$occurrence_no ==1190082)]<-'Lichnoscorpius'
occurenceDataKjellesvigWaering87$genus[which(occurenceDataKjellesvigWaering87$occurrence_no ==1150404)]<-'Coseleyscorpio'
occurenceDataKjellesvigWaering87$genus[which(occurenceDataKjellesvigWaering87$occurrence_no ==1039409)]<-'Pseudobuthiscorpius'
occurenceDataKjellesvigWaering87$genus[which(occurenceDataKjellesvigWaering87$occurrence_no ==1190058)]<-'Archaeophonus'
occurenceDataKjellesvigWaering87$genus[which(occurenceDataKjellesvigWaering87$occurrence_no ==1190055)]<-'Archaeophonus'
occurenceDataKjellesvigWaering87$genus[which(occurenceDataKjellesvigWaering87$occurrence_no ==1190062)]<-'Pseudoarchaeoctonus'
occurenceDataKjellesvigWaering87$genus[which(occurenceDataKjellesvigWaering87$occurrence_no ==1190189)]<-'Allopalaeophonus'
occurenceDataKjellesvigWaering87$genus[which(occurenceDataKjellesvigWaering87$occurrence_no ==1150405)]<-'Leioscorpio'

kjellesvig_waering_1987_defunct_families <- list(
  Stoermeroscorpioniidae=list("Stoermeroscorpio"),
  Allobuthiscorpiidae=list("Allobuthiscorpius"),
  Allopalaeophonidae=list("Allopalaeophonus"),
  Anthracoscorpionidae=list("Lichnoscorpius", "Coseleyscorpio"),
  Pseudobuthiscorpiidae=list("Pseudobuthiscorpius"),
  Paraisobuthidae=list("Paraisobuthus", "Leioscorpio")#Redo this to include Leioscorpio in correct family
)

for(i in 1:length(kjellesvig_waering_1987_defunct_families))
  for(j in 1:length(kjellesvig_waering_1987_defunct_families[[i]]))
    occurenceDataKjellesvigWaering87$kjellesvig_waering_1987[which(occurenceDataKjellesvigWaering87$genus == kjellesvig_waering_1987_defunct_families[[i]][j])]<-names(kjellesvig_waering_1987_defunct_families)[i]

#Might as well make this one A4
pdf("PDFs/KjellesvigWaering1987.pdf", width = 8.3, height = 11.7)
mar.default <- c(5,4,4,2) + 0.1
tax_range_time_RJG(occdf = occurenceDataKjellesvigWaering87, name = "genus", plot = TRUE, by="FAD", group_by = "kjellesvig_waering_1987", title="Kjellesvig Waering 1987", plot_names = TRUE, x_pad=50, x_range = c(445, 0))
dev.off()

##########################

# Stockwell 1989
occurenceData$stockwell_1989 = NA
stockwell_1989 <- list(
  Palaeophonidae=list("Palaeophonus", "Allopalaeophonus", "Dolichophonus"),
  Palaeoscorpiidae=list("Palaeoscorpius"),
  #Put Proscorpiids in quotes down the line
  Proscorpiids=list("Proscorpius","Archaeophonus", "Waeringoscorpio", "Labriscorpio"),
  Archaeoctonoids=list("Archaeoctonus","Pseudoarchaeoctonus","Loboarchaeoctonus"),
  Mesophonidae=list("Mesophonus","Mazonia","Heloscorpio","Phoxiscorpio"),
  Eoscorpiidae=list("Eoscorpius","Eobuthus","Isobuthus","Pareobuthus","Kronoscorpio"),
  Paraisobuthidae=list("Paraisobuthus","Telmatoscorpio"),
  Eoctonidae=list("Eoctonus"),
  Buthiscorpiidae=list("Buthiscorpius"),
  Allobuthiscorpiidae=list("Aspiscorpio"),
  Anthracoscorpionidae=list("Anthracoscorpio", "Allobuthus"),
  Orthosterns=list("Palaeopisthacanthus", "Compsoscorpius", "Mioscorpio")#Plus living families
  )

for(i in 1:length(stockwell_1989))
  for(j in 1:length(stockwell_1989[[i]]))
    occurenceData$stockwell_1989[which(occurenceData$genus == stockwell_1989[[i]][j])]<-names(stockwell_1989)[i]

occurenceDataStockwell89<-subset(occurenceData, !is.na(stockwell_1989))
occurenceDataStockwell89<-occurenceDataStockwell89[which(occurenceDataStockwell89$yearSpeciesPublished<1989),]

#These are the obsolete genera - write them to our subsetted data table based on occurrence_no
occurenceDataStockwell89$genus[which(occurenceDataStockwell89$occurrence_no==1190060)]<-'Stoermeroscorpio'
occurenceDataStockwell89$genus[which(occurenceDataStockwell89$occurrence_no ==1190058)]<-'Archaeophonus'
occurenceDataStockwell89$genus[which(occurenceDataStockwell89$occurrence_no ==1190055)]<-'Archaeophonus'
occurenceDataStockwell89$genus[which(occurenceDataStockwell89$occurrence_no ==1190062)]<-'Pseudoarchaeoctonus'
occurenceDataStockwell89$genus[which(occurenceDataStockwell89$occurrence_no ==1150404)]<-'Coseleyscorpio'
occurenceDataStockwell89$genus[which(occurenceDataStockwell89$occurrence_no ==1190079)]<-'Allobuthiscorpius'
occurenceDataStockwell89$genus[which(occurenceDataStockwell89$occurrence_no ==1190082)]<-'Lichnoscorpius'

#Apply families to the above
for(i in 1:length(stockwell_1989))
  for(j in 1:length(stockwell_1989[[i]]))
    occurenceDataStockwell89$stockwell_1989[which(occurenceDataStockwell89$genus == stockwell_1989[[i]][j])]<-names(stockwell_1989)[i]

pdf("PDFs/Stockwell_1989.pdf", width = 8, height = 8)
mar.default <- c(5,4,4,2) + 0.1
tax_range_time_RJG(occdf = occurenceDataStockwell89, name = "genus", plot = TRUE, by="FAD", group_by = "stockwell_1989", title="Stockwell 1989", plot_names = TRUE, x_pad=50, x_range = c(445, 0))
dev.off()

##########################

# Jeram 1994a
occurenceData$jeram_1994a = NA
jeram_1994a <- list(
    Palaeophonidae=list("Palaeophonus", "Allopalaeophonus", "Dolichophonus"),
    Palaeoscorpiidae=list("Palaeoscorpius"),
    #Put Proscorpiids in quotes down the line
    Proscorpiids=list("Proscorpius","Archaeophonus", "Waeringoscorpio", "Labriscorpio"),
    Archaeoctonoids=list("Archaeoctonus","Pseudoarchaeoctonus","Loboarchaeoctonus"),
    Mesophonidae=list("Mesophonus","Mazonia","Heloscorpio"),
    Eoscorpiidae=list("Eoscorpius","Eobuthus","Isobuthus","Pareobuthus","Kronoscorpio"),
    Paraisobuthidae=list("Paraisobuthus","Telmatoscorpio"),
    Paleosterni=list("Eoctonus","Buthiscorpius","Allobuthiscorpius","Aspiscorpio","Anthracoscorpio","Lichnoscorpius","Allobuthus","Coseleyscorpio"),
    Orthosterni=list("Palaeopisthacanthus", "Compsoscorpius", "Mioscorpio", "Gymnoscorpius", "Cryptoscorpius", "Corniops"),#Plus living families
    Centromachidae=list("Pulmonoscorpius", "Opsieobuthus", "Anthracochaerilus", "Phoxiscorpio", "Centromachus"),
    Gigantoscorpionidae=list("Gigantoscorpio","Petaloscorpio"),
    Incertae_sedis=list("Hubeiscorpio", "Scoloposcorpio", "Eskiscorpio", "Trachyscorpio")
)

for(i in 1:length(jeram_1994a))
  for(j in 1:length(jeram_1994a[[i]]))
    occurenceData$jeram_1994a[which(occurenceData$genus == jeram_1994a[[i]][j])]<-names(jeram_1994a)[i]

occurenceDataJeram94a<-subset(occurenceData, !is.na(jeram_1994a))
occurenceDataJeram94a<-occurenceDataJeram94a[which(occurenceDataJeram94a$yearSpeciesPublished<=1994),]

#These are the obsolete genera - write them to our subsetted data table based on occurrence_no
occurenceDataJeram94a$genus[which(occurenceDataJeram94a$occurrence_no==1190060)]<-'Stoermeroscorpio'
occurenceDataJeram94a$genus[which(occurenceDataJeram94a$occurrence_no==1190058)]<-'Archaeophonus'
occurenceDataJeram94a$genus[which(occurenceDataJeram94a$occurrence_no==1190055)]<-'Archaeophonus'
occurenceDataJeram94a$genus[which(occurenceDataJeram94a$occurrence_no==1190062)]<-'Pseudoarchaeoctonus'
occurenceDataJeram94a$genus[which(occurenceDataJeram94a$occurrence_no==1150404)]<-'Coseleyscorpio'
occurenceDataJeram94a$genus[which(occurenceDataJeram94a$occurrence_no==1190079)]<-'Allobuthiscorpius'
occurenceDataJeram94a$genus[which(occurenceDataJeram94a$occurrence_no==1190082)]<-'Lichnoscorpius'
occurenceDataJeram94a$genus[which(occurenceDataJeram94a$occurrence_no==1190189)]<-'Allopalaeophonus'

#Apply families to the above
for(i in 1:length(jeram_1994a))
  for(j in 1:length(jeram_1994a[[i]]))
    occurenceDataJeram94a$jeram_1994a[which(occurenceDataJeram94a$genus == jeram_1994a[[i]][j])]<-names(jeram_1994a)[i]

pdf("PDFs/Jeram_1994.pdf", width = 8, height = 8)
mar.default <- c(5,4,4,2) + 0.1
tax_range_time_RJG(occdf =   occurenceDataJeram94a, name = "genus", plot = TRUE, by="FAD", group_by = "jeram_1994a", title="Jeram 1994", plot_names = TRUE, x_pad=50, x_range = c(445, 0))
dev.off()

##########################

# Current status
# All recent only families are omitted
occurenceData$current = NA
current <- list(
  Proscorpiidae=list("Proscorpius","Archaeoctonus","Hydroscorpius","Labriscorpio","Pseudoarchaeoctonus","Waeringoscorpio"),
  Branchioscorpionidae=list("Branchioscorpio"),
  Dolichophonidae=list("Dolichophonus"),
  Acanthoscorpionidae=list("Acanthoscorpio"),
  Stenoscorpionidae=list("Stenoscorpio"),
  Allobuthiscorpiidae=list("Aspiscorpio"),
  Anthracoscorpionidae=list("Anthracoscorpio", "Allobuthus"),
  Buthiscorpiidae=list("Buthiscorpius"),
  Garnettiidae=list("Garnettius"),
  Gigantoscorpionidae=list("Gigantoscorpio","Petaloscorpio"),
  Centromachidae=list("Pulmonoscorpius", "Opsieobuthus", "Anthracochaerilus", "Phoxiscorpio","Centromachus"),
  Gallioscorpionidae=list("Gallioscorpio"),
  Heloscorpionidae=list("Heloscorpio"),
  Mazoniidae=list("Mazonia"),
  Mesophonidae=list("Mesophonus"),
  Willsiscorpionidae=list("Willsiscorpio"),
  Palaeoscorpiidae=list("Palaeoscorpius"),
  Praearcturidae=list("Praearcturus"),
  Spongiophonoidae=list("Spongiophonus"),
  Cyclophthalmidae=list("Cyclophthalmus"),
  Microlabiidae=list("Microlabius"),
  Palaeobuthidae=list("Palaeobuthus"),
  Eobuthidae=list("Eobuthus"),
  Eoscorpiidae=list("Eoscorpius","Trachyscorpio","Eskiscorpio"),
  Isobuthidae=list("Isobuthus", "Feistmantelia", "Boreoscorpio", "Bromsgroviscorpio"),
  Kronoscorpionidae=list("Kronoscorpio"),
  Pareobuthidae=list("Pareobuthus"),
  Paraisobuthidae=list("Paraisobuthus"),
  Scoloposcorpionidae=list("Benniescorpio","Scoloposcorpio"),
  Telmatoscorpionidae=list("Telmatoscorpio"),
  Loboarchaeoctonidae=list("Loboarchaeoctonus"),
  Waterstoniidae=list("Waterstonia"),
  Palaeophonidae=list("Palaeophonus"),
  Orthosternina_Incertae_sedis=list("Compsoscorpius","Corniops","Suraju"),
  Palaeopisthacanthidae=list("Palaeopisthacanthus","Cryptoscorpius"),
  Chaerilobuthidae=list("Chaerilobuthus"),
  Palaeotrilineatidae=list("Palaeotrilineatus"),
  Sucinlourencoidae=list("Sucinlourencous"),
  Chaerilidae=list("Electrochaerilus","Chaerilus"),
  Protobuthidae=list("Protobuthus"),
  Archaeobuthidae=list("Archaeobuthus"),
  Palaeoburmesebuthidae=list("Betaburmesebuthus", "Palaeoburmesebuthus","Spinoburmesebuthus","Paranotaburmesebuthus"),
  Buthidae=list("Centruroides","Cretaceousbuthus","Microcharmus","Microtityus","Palaeoakentrobuthus","Palaeoisometrus","Palaeogrosphus","Palaeolychas","Palaeoprotobuthus","Palaeospinobuthus","Tityus","Uintascorpio"),
  Ananteridae=list("Archaeoananteroides","Palaeoananteris","Palaeotityobuthus"),
  Protochactidae=list("Protochactas"),
  Chactidae=list("Araripescorpius", "Chactas"),
  Palaeoeuscorpiidae=list("Archaeoscorpiops","Burmesescorpiops","Palaeoeuscorpius"),
  Euscorpiidae=list("Eoeuscorpius"),
  Hemiscorpiidae=list("Cretaceoushormiops","Cretaceousopisthacanthus","Protoischnurus"),
  Scorpionidae=list("Mioscorpio","Sinoscorpius"),
  Scorpiones_incertae_sedis=list("Brontoscorpio","Eramoscorpius","Gondwanascorpio","Hubeiscorpio","Liassoscorpionides","Palaeomachus","Permomatveevia","Titanoscorpio","Wattisonia"),
  Neoscorpionina_incertae_sedis=list("Gymnoscorpius")

)
for(i in 1:length(current))
  for(j in 1:length(current[[i]]))
    occurenceData$current[which(occurenceData$genus == current[[i]][j])]<-names(current)[i]

occurenceDataNAs<-occurenceData[which(is.na(occurenceData$current)),]
occurenceDataCurrent<-subset(occurenceData, !is.na(current))

#Doesn't fit nicely on A4 - enbiggen a little
factor = 1.6
pdf("PDFs/Current_taxonomy.pdf", width = 8.3*factor, height = (8.3*factor)*(11.7/8.3))
mar.default <- c(5,4,4,2) + 0.1
tax_range_time_RJG(occdf = occurenceDataCurrent, name = "genus", plot = TRUE, by="FAD", group_by = "current", title="Current taxonomy", plot_names = TRUE, x_pad=75, x_range = c(430, 0))
dev.off()


######################################################################################################################
# Additional plots - collectors curve, and period histograms
######################################################################################################################

#Create time bins
bins <- time_bins(rank = "period")
#Only want to count accepted species - filter for taxa known to species
occurenceDataSpecies<-occurenceData[occurenceData$accepted_rank=="species",]

#For each species, lets use the name, plus the min and max age across known occurrences
countsDF <- data.frame()
for (species in unique(occurenceDataSpecies$accepted_name))
{
  subsetBySpecies<-occurenceDataSpecies[occurenceDataSpecies$accepted_name==species,]
  speciesMax<-max(subsetBySpecies$max_ma)
  speciesMin<-min(subsetBySpecies$min_ma)
  newRow<-data.frame(Species = species, min_ma = speciesMin,  max_ma = speciesMax)
  countsDF<-rbind(countsDF,newRow)
}

#We can use Palaeoverse to bin this
countsDF<-bin_time(occdf = countsDF, bins = bins, method = "mid")
#And then write that as a Period in the DF for the X axis plotting
countsDF$Period <- bins[countsDF$bin_assignment,2]

#now lets plot using the discrete axis from the deeptime package
bars<-ggplot(countsDF, aes(x=factor(Period))) +
  geom_bar() + scale_x_discrete("Geological Period", breaks=NULL, limits = bins[-c(1,2),2], labels = NULL, expand = expansion(add = .5)) +
  coord_geo(expand = TRUE, skip = NULL, abbrv = TRUE) +
  theme_minimal() +
  theme(plot.title = element_text(hjust = 0.5), panel.border = element_rect(color="black", fill=NA)) +
  theme(axis.ticks.length.x = unit(0, "lines")) +
  scale_y_continuous(limits = c(0,70),expand = c(0, 0)) +
  labs(y="Number of fossil scorpion species described", title = "The distribution of scorpion fossil ages")

#Next, lets create our collector curve
#For each species, we can collect the name, and the year it was puvlished
collectorsCurve <- data.frame()
for (species in unique(occurenceDataSpecies$accepted_name))
{
  subsetBySpecies<-occurenceDataSpecies[occurenceDataSpecies$accepted_name==species,]
  year<-min(subsetBySpecies$yearSpeciesPublished)
  newRow<-data.frame(Species = species, year = year)
  collectorsCurve<-rbind(collectorsCurve,newRow)
}

#Using this we can then create a dataframe to form the basis of the collectors curve graph
countsDF2 <- data.frame()
for (i in 1835:2024)
{
  newRow<-data.frame(Year = i, Count = sum(collectorsCurve$year<i))
  countsDF2<-rbind(countsDF2,newRow)
}

#We can now plot it
cc<-ggplot(countsDF2) + geom_line(mapping = aes(x=Year, y=Count)) +
  scale_y_continuous(expand = c(0,0),limits = c(0,150)) +
  scale_x_continuous(expand = c(0,0))  +
  theme_minimal() +
  theme(plot.title = element_text(hjust = 0.5), panel.border = element_rect(color="black", fill=NA)) +
  labs(y="Number of fossil scorpion species described", title = "A collector's curve for fossil scorpions") +
  geom_vline(xintercept = 1986.5, linetype="dashed", color="gray") + annotate(geom = "text", x = 1983, y = 124, label = "Kjellesvig-Waering 1986",  color="gray", angle = 90) +
  geom_vline(xintercept = 1949.5, linetype="dashed", color="gray") + annotate(geom = "text", x = 1946, y = 129, label = "Petrunkevitch 1949",  color="gray", angle = 90) +
  geom_vline(xintercept = 1994.5, linetype="dashed", color="gray") + annotate(geom = "text", x = 1992, y = 136, label = "Jeram 1994",  color="gray", angle = 90) +
  geom_vline(xintercept = 1913.5, linetype="dashed", color="gray") + annotate(geom = "text", x = 1910, y = 128, label = "Petrunkevitch 1913",  color="gray", angle = 90)

#Using ggsave will, by default, create a PDF we don't need called Rplots.pdf - setting PDF to null stops this
pdf(NULL)
#We can save this to a file using gridExtra package
ggsave(filename = "PDFs/Scorpion_histogram_collector_curve.pdf",grid.arrange(bars,cc, ncol=2),width = 14, height = 6)

#Finally, we can replot the histograms for different years to see descriptions through time
# First initialize a plot list
plotList <- list()

#Then do plots
count <- 0
for (i in seq(1850,2025,20))
{
  count<-count+1
  countsDF3 <- data.frame()
  for (species in unique(occurenceDataSpecies$accepted_name))
  {
    subsetBySpecies<-occurenceDataSpecies[occurenceDataSpecies$accepted_name==species,]
    subsetBySpecies<-subsetBySpecies[subsetBySpecies$yearSpeciesPublished<i,]
    if(length(subsetBySpecies$occurrence_no)>0)
    {
      speciesMax<-max(subsetBySpecies$max_ma)
      speciesMin<-min(subsetBySpecies$min_ma)
      newRow<-data.frame(Species = species, min_ma = speciesMin,  max_ma = speciesMax)
      countsDF3<-rbind(countsDF3,newRow)
    }
  }
  #We can use Palaeoverse to bin this for each plot
  countsDF3<-bin_time(occdf = countsDF3, bins = bins, method = "mid")
  #And then write that as a Period in the DF for the x axis for each plot
  countsDF3$Period <- bins[countsDF3$bin_assignment,2]

  #Add to the plot list
  plotList[[count]]<-ggplot(countsDF3, aes(x=factor(Period))) +
    geom_bar() + scale_x_discrete("Geological Period", breaks=NULL, limits = bins[-c(1,2),2], labels = NULL, expand = expansion(add = .5)) +
    coord_geo(expand = TRUE, skip = NULL, abbrv = TRUE) +
    theme_minimal() +
    theme(plot.title = element_text(hjust = 0.5), panel.border = element_rect(color="black", fill=NA)) +
    theme(axis.ticks.length.x = unit(0, "lines")) +
    scale_y_continuous(limits = c(0,70),expand = c(0, 0)) +
    labs(y="Described scorpion species", title = paste("The distribution of scorpion fossil ages -",i))
}

#Now save this plot
ggsave(filename = "PDFs/Scorpion_histograms_by_year.pdf",do.call(grid.arrange,plotList),width = 14, height = 14)
